function topbetas=beta_draws_bma(bmao,stdev)
% matrix with coefficients for the best models in a bma object.     
%
%function topbetas=beta_draws_bma(bmao,stdev)
%
% Note that default inputs may be obtained by providing an empty value (e.g. '') or NaN
%% INPUTS:
% * bmao: a 'bma' object (as e.g. resulting from bms)
% * stdev (optional): if stdev=FALSE then beta.draws.bma returns the 
%       (conditional) posterior expected values of the coefficients 
%       (i.e. 'Bayesian coefficients'). If stdev=TRUE it returns their 
%        posterior standard deviations. 
%% OUTPUT:
% Each column presents the coefficents for the model indicated by its 
%       column name. The zero coefficients are the excluded covariates per 
%       model. Note that the coefficients returned are only those of the 
%       best (500) models encountered by the bma object (cf. argument nmodels  of bms). 
%
%% EXAMPLE:
% load datafls;
% mm=bms(datafls,'','',20);
% beta_draws_bma(mm) 
%
%% SEE ALSO
% bms, pmp.bma
% 
% Equivalent function in R: beta.draws.bma
% Author: Stefan Zeugner 2010 
% Url: http://bms.zeugner.eu
    
    is_bma(false);
    
    if nargin<2; stdev=false;end
    try 
        stdev=logical(stdev(1));
    catch
        error('Argument ''stdev'' must be logical!');
    end
    
    
    evalinR(['bmstmp=beta.draws.bma(bma' bmao.suffix ',stdev='  num2str(stdev) ')']);
    topbetas = rcell2mat(getRdata('bmstmp'));
    
