function isit = is_bma(bmao,silent)
%Tests for a 'bma' Object
%
%isit = is_bma(bmao,silent)
%
%% INPUTS:
%required inputs:
% * bmao: a 'bma' object (as e.g. resulting from bms)
%optional inputs:
% * silent: logical, default false; if true then is_bma returns error
%   messages
%
%% OUTPUT:
%   a logical whether bmao has all required prooperties of a bma object and
%   is mirrored in an open R session
%
%% EXAMPLE:
% load datafls;
% mm=bms(datafls);
% is_bma(mm,false);
% aa=1;
% is_bma(aa,false);
%________________________________________________
%
%% SEE ALSO
% bms, isBMSopen
% 
% Equivalent function in R: is.bma
% Author: Stefan Zeugner 2010 
% Url: http://bms.zeugner.eu



    if nargin<2; silent=true; end;
    errmsg1='provided argument must be ''bma'' structure as resulting from function ''bms''';
    
    
    if ~isstruct(bmao); 
        isit=false;
        if not(silent); error(errmsg1); end
        return;
    end;
    if ~isfield(bmao,'suffix'); 
        isit=false;
        if not(silent); error(errmsg1); end
        return;
    end;
    
    isit=isBMSopen(silent);
    if not(isit); return; end;
     evalinR(['bmstmp = is.bma_matlab(''bma', bmao.suffix, ''')']);
     isit = getRdata('bmstmp');
    
    if not(isit) & not(silent)
        error(['bma object ''bma', bmao.siuffix, ''' does not exist in R workspace']);
    end
    
    