function [bmsstatus, msg] = libraryBMS()
% opens an R session and loads the BMS library
%
%[bmsstatus, msg] = libraryBMS()
%
%OUTPUTS:
% * bmsstatus: a boolean whether the R session is open
% * msg: in case opening fails and a second output argument is requested,
%       then error messages are written into msg
%
%EXAMPLE: 
% libraryBMS
%_________________________
%
%SEE ALSO
% closeBMS, bms, saveRworkspace, loadRworkspace
%
%Equivalent function in R: library(BMS)
%Author: Stefan Zeugner 2010 
%Url: http://bms.zeugner.eu


bmsstatus = false;
msg = '';

% Use a global variable for the connection handle.
global RBMS_LinkHandle
openup=false;

% Check if a connection exists
if isempty(RBMS_LinkHandle)
    % if it seems empty, call the StatConnector and initialize an R session
    try
        RBMS_LinkHandle = actxserver('StatConnectorSrv.StatConnector');
        RBMS_LinkHandle.Init('R');
        openup=true;
    catch
        bmsstatus = false;
        RBMS_LinkHandle = [];
        if nargout <1
            error('Cannot connect to R.\n%s',lasterr);
        else
            msg = lasterr;
        end
    end
end
  

  %loading the BMS library within R
  RBMS_LinkHandle.EvaluateNoReturn('bmsloaded=require(BMS)');
  bmsstatus=RBMS_LinkHandle.GetSymbol('bmsloaded');
  
  if not(bmsstatus) 
        %if it did not work, try installing BMS in R
        msg = 'BMS library seems to be not installed. Trying to install...';
        if nargout <1
            warning(msg); msg='';
        end
        RBMS_LinkHandle.EvaluateNoReturn('install.packages(''BMS'',repos=''http://cran.r-project.org'')');
        RBMS_LinkHandle.EvaluateNoReturn('bmsloaded=require(BMS)');
        bmsstatus=RBMS_LinkHandle.GetSymbol('bmsloaded');
  end
  

   if not(bmsstatus) 
        if nargout <1
            error('Cannot load BMS library');
        else
            msg = lasterr;
        end
    end

    
    
    
   if openup
        %source the file matlab_BMS.r to R
        sfilepath=mfilename('fullpath');
        sfilename=mfilename;
        sfilepath=sfilepath(1:(end-length(sfilename)));
        sfilepath=strrep(sfilepath,'\','/');
        RBMS_LinkHandle.EvaluateNoReturn(['source(''', sfilepath, 'other/matlab_BMS.r'')']);
        scdpath=pwd; scdpath=strrep(scdpath,'\','/');
        RBMS_LinkHandle.EvaluateNoReturn(['setwd(''', scdpath , ''')']);
        
        %adding the toolbox directory to matlab search path
        addpath(sfilepath); addpath([sfilepath 'other/']);
    end