
function soutchar=Cstr2format(csIn,lBlanksbetween,lRowsbetween,lLeadingBlanks,cColAlign,cRowAlign)
%This function converts a cellstring array into a char, by using the layout
%   options given in the optional inputs: i.e. it makes a 'nice table' out of
%   a cell string
%    if you don't want to specify an optional input, put 'nan' as in the
%    example below
%____________________________________________________
%OUTPUTS
%   soutchar: char string containing a nicely formatted output
%____________________________________________________
%INPUTS
%csIn (required) is a cell array of strings
%lBlanksbetween (optional) is the number of blanks between columns
%   (default=1)
%lRowsbetween (optional) is the number of empty rows between the rows to be
%   displayed (default=0) (currently decactivated)
%lLeadingBlanks (optional) is the number of blanks to be put before the out
%   (default=0)
%cColAlign (optional) is a double array with alignment of columns (-1=left, 0=center, 1=right)
%   (default=vector of -1)
%cRowAlign (optional) is a double array with alignment of rows (-1=left, 0=center,%1=right) 
%   (default=vector of -1)
%   cRowAlign (optional) overrides the formatting of cColAlign; if you want cRowAlign not
%   to change the cColAlign alignment for a specific row, put in another
%   number than -1, 0 or 1 in the entry for that specifc row
%____________________________________________________    %
%EXAMPLE:
%   cellstringinput={'abc','defg';'hijkl','mn'}
%   formatedOutput=fncCstr2format(cellstringinput,4,nan,10,[1;0],[-1;9])
%______________________________________________________________________
%   Martin Feldkircher & Stefan Zeugner 2006




    error(nargchk(1, 6, nargin))
    
        if nargin<6,cRowAlign=nan;end
        if nargin<5,cColAlign=nan;end
        if nargin<4,lLeadingBlanks=nan;end
        if nargin<3,lRowsbetween=nan;end
        if nargin<2,lBlanksbetween=nan;end

        if isnan(lBlanksbetween), lBlanksbetween=1;end
        if isnan(lRowsbetween), lRowsbetween=0;end
        if isnan(lLeadingBlanks), lLeadingBlanks=0;end
        if isnan(cColAlign), cColAlign=-ones(size(csIn,2),1); end
        if isnan(cRowAlign), cRowAlign=2*ones(size(csIn,1),1); end        

for i=1:size(csIn,2)
   scont{i}=char(csIn{:,i});
end

for i=1:size(cColAlign,1)
    if ismember(cColAlign(i,1),[-1,0,1])
        scont{i}=strjust(scont{i},convalign(cColAlign(i,1)));
    end
end

for i=1:size(cRowAlign,1)
    if ismember(cRowAlign(i,1),[-1,0,1])
        for j=1:length(scont)
            scont{j}(i,:)=strjust(scont{j}(i,:),convalign(cRowAlign(i,1)));
        end
    end
end


scoldelim=char(zeros(size(csIn,1),lBlanksbetween));
stempcont=[char(zeros(size(csIn,1),lLeadingBlanks)) scont{1}];
for i=2:size(csIn,2)
   stempcont=[stempcont scoldelim scont{i}];
end


%if lRowsbetween>0
%    shihi=''
%     for i=1:size(stempcont,1)
%         strcat( shihi,' \n ', stempcont(i,:), repmat(' \n ' ,1,lRowsbetween))
%        shihi=sprintf(strcat( shihi,' \n ', stempcont(i,:), repmat(' \n ' ,1,lRowsbetween)));
%     end
% end
% disp(shihi)

soutchar=stempcont;


function sOut=convalign(dIn)
switch dIn
    case -1
        sOut='left';
    case 0
        sOut='center';
    case 1
        sOut='right';
end

    