function [X_struct, burn, iter, nmodel, mcmc, g, mprior, mprior_size, user_int, logfile] = bms_checkargs(X_data, burn, iter, nmodel, mcmc, g, mprior, mprior_size, user_int, logfile, verbose)

%X_data
errmsg='X_data must be a numeric matrix, or a dataset, or a structure (see help bms)!';

    X_struct=X_data;
    if strcmpi(class(X_struct),'struct')
        try
            X_data=X_struct.data;
        catch
            error(errmsg); 
        end
        try; X_varnames=X_struct.Properties.VarNames; end
        try; X_obsnames=X_struct.Properties.ObsNames; end        
    elseif strcmpi(class(X_struct),'dataset')
        try
            X_data=double(X_struct);
        catch
            error(errmsg); 
        end
        try; X_varnames=X_struct.Properties.VarNames; end
        try; X_obsnames=X_struct.Properties.ObsNames; end        
        X_struct = struct;
    end



if not(isnumeric(X_data)); 
    error(errmsg); 
end;

xsize=size(X_data); if length(xsize)~=2; error('X_data must be a two-dimensional matrix'); end;
if xsize(2)<2; error('X_data must at least have 2 columns'); end;
%need to do this since matlab 6 is too stupid to properly handle
%cellstr(num2str( ))
if not(exist('X_varnames')); 
    X_varnames=cell(xsize(2),1);
    X_varnames{1}='y';
    for j=1:(length(X_varnames)-1);
        X_varnames{j+1}=num2str(j);
    end;
else
    X_varnames=X_varnames(:);
    if length(X_varnames) ==xsize(2)-1; X_varnames=vertcat({'y'}, X_varnames); end;
    if length(X_varnames) ~=xsize(2); error('Dimensions of Variable Names do not match data'); end;
end;
if not(exist('X_obsnames')); 
    X_obsnames=cell(xsize(1),1);
    for j=1:length(X_obsnames);
        X_obsnames{j}=num2str(j);
    end;
else
    X_obsnames=X_obsnames(:);
    if length(X_obsnames) ~=xsize(1); error('Dimensions of Observations Names do not match data'); end;
end;
    
ixofgood=~any(isnan(X_data),2);
X_data=X_data(ixofgood,:); X_obsnames=X_obsnames(ixofgood);
if not(isequal(size(X_data),xsize)); warning('X_data contains NaN values - the corresponding rows were removed'); end;

X_struct.data=X_data; X_struct.Properties.VarNames= X_varnames; X_struct.Properties.ObsNames= X_obsnames;
xsize=size(X_data);

%burn
if not(isnan(burn))
    errmsg='burn must be a scalar integer>0';
    if not(isnumeric(burn)); error(errmsg); end;
    try
        burn=floor(burn(1));
    catch
        error(errmsg);
    end
    if length(burn)~=1; error(errmsg); end;
    if any(burn<0); error(errmsg); end;
end
   
%iter
if not(isnan(iter))
    errmsg='iter must be a scalar integer>0';
    if not(isnumeric(iter)); error(errmsg); end;
    try
        iter=floor(iter(1));
    catch
        error(errmsg);
    end
    if length(iter)~=1; error(errmsg); end;
    if any(iter<0); error(errmsg); end;
end

%nmodel
if not(isnan(nmodel))
    errmsg='nmodel must be a scalar integer>=0';
    if not(isnumeric(nmodel)); error(errmsg); end;
    try
        nmodel=floor(nmodel(1));
    catch
        error(errmsg);
    end
    if length(nmodel)~=1; error(errmsg); end;
    if any(nmodel<0); error(errmsg); end;
end

%mcmc
if not(isnan(mcmc))
    errmsg='mcmc must be character among the following: ''bd'', ''rev.jump'', or ''enumerate'' ';
    if not(isstr(mcmc)); error(errmsg); end;
    if size(mcmc,1)~=1; error(errmsg); end;
    mcmc=lower(mcmc);
    mcmcgood=false;
    if ~isempty(findstr(mcmc,'enum')); mcmcgood=true; end;
    if ~isempty(findstr(mcmc,'bd')); mcmcgood=true; end;
    if ~isempty(findstr(mcmc,'rev.jump')); mcmcgood=true; end;
    if not(mcmcgood); error(errmsg); end;
end

%g
if not(isnan(g))
    errmsg=['g must be a character according to help bms, or a positive scalar (real)'];
    if not(isstr(g)); 
        if not(isreal(g)); error(errmsg); end;
        if (g<=0); error(errmdg); end;
        g=num2str(g);
    else
        if size(g,1)~=1; error(errmsg); end;     
    end;
    g=upper(g);
    itsgood=false;
    if ~isempty(findstr(g,'RIC')); itsgood=true; end;
    if ~isempty(findstr(g,'UIP')); itsgood=true; end;
    if ~isempty(findstr(g,'BIC')); itsgood=true; end;
    if ~isempty(findstr(g,'HQ')); itsgood=true; end;    
    if ~isempty(findstr(g,'EB')); itsgood=true; end;        
    if ~isempty(findstr(g,'HYPER')); itsgood=true; end;            
    if not(itsgood); error(errmsg); end;    
    
end


%mprior
if not(isnan(mprior))
    errmsg='mprior must be character among the following: ''uniform'', ''fixed'', or ''random'' ';
    if not(isstr(mprior)); error(errmsg); end;
    if size(mprior,1)~=1; error(errmsg); end;
    mprior=lower(mprior);
    itsgood=false;
    if ~isempty(findstr(mprior,'unif')); itsgood=true; end;
    if ~isempty(findstr(mprior,'fix')); itsgood=true; end;
    if ~isempty(findstr(mprior,'rand')); itsgood=true; end;
    if not(itsgood); error(errmsg); end;    
end


%mprior_size
if not(isnan(mprior_size))
    errmsg=['mprior_size must be a real scalar between 0 and ' num2str(xsize(2)-1)];
    if not(isreal(mprior_size)); error(errmsg); end;
    if (mprior_size<=0)||(mprior_size>=(xsize(2)-1));  error(errmsg); end;
end


% user_int
if isnan(user_int); user_int=true; end;
try 
    user_int=logical(user_int(1)); 
catch
    error('user_int must be logical');
end;

% logfile
if isnan(logfile); logfile=false; end;
try 
    logfile=logical(logfile(1)); 
catch
    error('logfile must be logical');
end;

