function csOut=c2cstr(din,sformat,bJustifyDelimiter)
% function csOut=c2cstr(din,sformat,bJustifyDelimiter)
%
% This function converts a double array into a nicely-looking cell array of
%   strings
%_______________________________________
%OUTPUTS:
% csOut: cellstring array of strings
%_______________________________________
%INPUTS:
% din (required): double matrix 
% sformat (optional): format and precision of numbers to be displayed (see
%       MATLAB help: 'fprintf'). Default='%-5G'
% bJustifyDelimiter (optional): If true, then the the numbers are justified
% (aligned) along the decimal delimiter '.'
%_______________________________________
% This function is intended to be used only by other functions, so there
% are no input checks
%_______________________________________
%   Martin Feldkircher & Stefan Zeugner 2006
    if nargin<2,sformat='%-5G';end
    if isnan(sformat)|isempty(sformat),sformat='%-5G';end
    if nargin<3,bJustifyDelimiter=1;end
    csTemp=repmat({NaN},size(din,1),size(din,2));
    for cc=1:size(din,2)
        csTemp(:,cc)=c2cstrcol(din(:,cc),sformat,bJustifyDelimiter);
    end
    csOut=csTemp;


function csOutcol=c2cstrcol(din,sformat,bJustifyDelimiter)
    if str2num(strtok(version,'.'))<7,csOutcol=cellstr(num2str(din));return;end
    
    csTemp = cellstr(num2str(din(:,1),sformat));
    if bJustifyDelimiter
        [sleft,sright]=strtok(csTemp,'.');
        csOutcol=strcat(cellstr(strjust(char(sleft),'right')),sright);
    else
        csOutcol=csTemp;
    end