function plotlines=plotConv(bmao)
%Plot Convergence of BMA Sampler
%
%plotlines=plotConv(bmao)
%
%% INPUTS:
%required inputs:
% * bmao: a 'bma' object (as e.g. resulting from bms)
%
%% OUTPUT:
%  Plots the posterior model probabilities for the best (500) models
%  contained in bmao (cf. argument nmodel in function bms) ; 
%  PMP (exact) and PMP (MCMC) correspond to columns in the function pmp_bma
%  if an output argument is requested then this function returns a matrix with the two
%  lines it plots
%
%% EXAMPLE:
% load datafls;
% mm=bms(datafls,[],[],[],[],[],[],[],false);
% plotConv(mm);
%________________________________________________
%
%% SEE ALSO
% pmp_bma
% 
% Equivalent function in R: plotConv
% Author: Stefan Zeugner 2010 
% Url: http://bms.zeugner.eu


    pmps=pmp_bma(bmao);
    
    normfactor=sum(pmps(:,1))/sum(pmps(:,2));
    tmpmp=pmps;
    tmpmp(:,1)=pmps(:,2)*normfactor;
    tmpmp(:,2)=pmps(:,1);
    
    if nargout>0
        plotlines=tmpmp;
    end
    
    
     pp1=plot(tmpmp(:,1),'b-');
     hold on;
     pp2=plot(tmpmp(:,2),'r-');
     hold off;
    
     pmpcor=corrcoef(tmpmp);
     title(['Posterior Model Probabilities (Corr: ', num2str(pmpcor(2,1)), ')']);
     xlabel('Index of best models');
     legend([pp1 pp2],'PMP (MCMC)','PMP (Exact)');
    
   