function plotlines=plotModelsize(bmao,exact)
%Plot Model Size Distribution
%
%plotlines=plotModelsize(bmao,exact)
%
%% INPUTS:
%required inputs:
% * bmao: a 'bma' object (as e.g. resulting from bms)
%optional inputs:
% * exact:  if exact==true, then the posterior model distribution is based
%       on the best models of bmao and their marginal likelihoods;  
%       if false (default) then the distribution is based on all
%       encountered models and their MCMC frequencies (cf. section 'Notes' in
%       help coef_bma)   
%
%% OUTPUT:
% As a default, plotModelsize plots the posterior model size distribution
% as a blue line, and the prior model distribution as a dashed red line. 
%  If an output argument is requestedn, then it returns a matrix, whose 
%  1st column holds the prior model size distribution from modoel size 0 to
%  K; while the 2nd coolumn holds the posterior model size
%
%% EXAMPLE:
% load datafls;
% mm=bms(datafls,[],[],[],[],[],[],'uniform');
% plotModelsize(mm);
%________________________________________________
%
%% SEE ALSO
% bms, plotConv, image_bma, density_bma
% 
% Equivalent function in R: plotModelsize
% Author: Stefan Zeugner 2010 
% Url: http://bms.zeugner.eu

    if nargin<2; exact=false; end;
    try
        exact=logical(exact(1));
    catch
        error('argument ''exact'' must be logical!');
    end
    
     is_bma(bmao,false);
    
    evalinR(['bmstmp = modelsize_matlab(bma' bmao.suffix ')']);
    priorpost=getRdata('bmstmp');
    
    if nargout>0
        plotlines=priorpost;
    end
    msizes=0:(length(priorpost(:,2))-1); msizes=msizes(:);
    postdens=priorpost(:,2); postdens=postdens(:);
    priordens=priorpost(:,1); priordens=priordens(:);
    postmean=sum(postdens.*msizes);
    

    
     pp1=plot(msizes,priordens,'r--');
     hold on;
     pp2=plot(msizes,postdens,'b-',msizes,postdens,'kx');
     hold off;
    
     title(['Posterior Model Size Distribution (Mean: ', num2str(postmean), ')']);
     xlabel('Model Size');
     legend([pp2(1) pp1 ],'Posterior','Prior');

    
    
   