function saveRworkspace(filepath)
% saves the variables in the R session used for BMS
%
%saveRworkspace(filepath)
%
%NOTES:
% If you would like to save a workspace with bma objects, you should save
% the corresponding R objects as well - otherwise you might not be able to
% use them further on
%
%EXAMPLE: 
% libraryBMS % open BMS
% load datafls
% mm=bms(datafls); %create a bma object
% saveRworkspace 'myBMA'; %save R stuff to an .RData file
% save 'myBMA'; %save Matlab stuff to a .mat file
% closeBMS
% clear; %clear everything
% 
% %now load the session again:
% libraryBMS;
% load 'myBMA';
% loadRworkspace 'myBMA';
% print_bma(mm);
%
%_________________________
%
%SEE ALSO
% closeBMS, bms, libraryBMS, loadRworkspace
%
%Equivalent function in R: save.image
%Author: Stefan Zeugner 2010 
%Url: http://bms.zeugner.eu




   isBMSopen(false);
   if nargin<1
        filepath='Rworkspace.RData';
   end
   
   filepath=strrep(filepath,'\','/');
   dirdelims=regexp(filepath,'/');
   if length(dirdelims)>0 
       filename=filepath((dirdelims(end)+1):end);
       filedir =filepath(1:(dirdelims(end))) ;
   else
       filename=filepath;
       filedir = '';
   end
   
   if not(isempty(filedir))
   if not(exists(filedir,'dir')>0)
       error('specified directory does not exist');
   end
   end 
   
   if length(filename)>6
   if not(strcmpi(filename((end-5):end),'.RData'))
       filename = [filename '.RData'];
   end
   else
       filename = [filename '.RData'];
   end
   
   
   spwdpath=pwd;
   spwdpath=strrep(spwdpath,'\','/');
   evalinR(['oldpath=getwd(); setwd(''' spwdpath ''')']);
   evalinR(['save.image(''' filedir filename ''');']);
   evalinR(['setwd(oldpath); rm(oldpath);']);
   