function sumstats=summary_bma(bmao)
%Summary Statistics for a 'bma' Object
%
%print_bma(bmao)
%
%% INPUTS:
%required inputs:
% * bmao: a 'bma' object (as e.g. resulting from bms)
%
%% OUTPUT:
%  A cell array summarizing the results of a call to bms:
% * Mean no. of Regressors 	the posterior mean of model size
% * Draws 	the number of iterations (ex burn-ins)
% * Burnins 	the number of burn-in iterations
% * Time 	the time spent on iterating through the model space
% * No. of models visited 	the number of times a model was accepted (including burn-ins)
% * Modelspace 2^K 	the total model space 2^K
% * Percentage visited 	No. of models visited/Modelspace*100
% * Percentage Topmodels 	number of times the best models were drawn in percent of Draws
% * Corr. PMP 	the correlation between the MCMC frequencies of the best models (the number of times they were drawn) and their marginal likelihoods.
% * No. Obs. 	Number of observations
% * Model Prior 	a character conforming to the argument mprior of bms, and the expected prior model size
% * g-prior 	a character corresponding to argument g of function bms
% * Shrinkage-Stats 	Posterior expected value und standard deviation (if applicable) of the shrinkage factor. Only included if argument g.stats of function bms was set to TRUE
%
%% EXAMPLE:
% load datafls;
% mm=bms(datafls);
% testsum=summary_bma(mm);
% disp(testsum); %displays the contents
% summary_bma(mm); %displays them nicely
%________________________________________________
%
%% SEE ALSO
% bms, coef_bma, print_bma
% 
% Equivalent function in R: summary.bma
% Author: Stefan Zeugner 2010 
% Url: http://bms.zeugner.eu
    
    
    is_bma(false);
    
    
    if nargout==0;
        lLeadBlanks=4;
        disp(Cstr2format(bmao.summary,6,0,5,[-1;1]))
    else
        sumstats = bmao.summary;
    end